<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Vælg terminalens skrifttype</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Skrifttype:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Bookmarks</source>
        <translation>Bogmærker</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Tryk på &quot;%1&quot; for at se terminalen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Næste faneblad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Forrige faneblad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Left</source>
        <translation>Flyt faneblad til &amp;venstre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>Move Tab &amp;Right</source>
        <translation>Flyt faneblad til &amp;højre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Opdel terminal &amp;vandret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Opdel terminal &amp;lodret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Sammenfold underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Ryd aktiv terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <source>Keep window open when it loses focus</source>
        <translation>Hold vinduet åbent når det ikke er i fokus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Forrige faneblad i historik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Næste faneblad i historik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Tab</source>
        <translation>Faneblad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Go to</source>
        <translation>Gå til</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Øverste underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Nederste underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Venstre underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;Højre underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Copy &amp;Selection</source>
        <translation>Kopiér &amp;markering</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste Clip&amp;board</source>
        <translation>Indsæt &amp;udklipsholder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Paste S&amp;election</source>
        <translation>Indsæt m&amp;arkering</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;in</source>
        <translation>Zoom &amp;ind</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom &amp;out</source>
        <translation>Zoom &amp;ud</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Zoom rese&amp;t</source>
        <translation>Zoom &amp;nulstil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>&amp;Find...</source>
        <translation>&amp;Søg...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Handle history...</source>
        <translation>Håndter historik...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Gem session</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Indlæs session</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Menu til/fra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Rename session</source>
        <translation>Omdøb session</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nyt faneblad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nyt faneblad fra &amp;forudindstilling</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="368"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;Vandrette terminaler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;Lodrette terminaler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 Terminal&amp;er</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Luk faneblad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nyt vindue</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Indstillinger...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Skjul vindueskanter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Vis fanebladslinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Toggle Bookmarks</source>
        <translation>Bogmærker til/fra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Nederst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>&amp;Top</source>
        <translation>&amp;Øverst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Right</source>
        <translation>&amp;Højre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>&amp;Left</source>
        <translation>&amp;Venstre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>&amp;Tabs Layout</source>
        <translation>Layout for &amp;faneblade</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;None</source>
        <translation>&amp;Ingen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Layout for &amp;rullebjælke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Blokmarkør</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Understreget markør</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Lodret streg markør</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Tastaturmarkørens form</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Exit QTerminal</source>
        <translation>Afslut QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Do not ask again</source>
        <translation>Spørg ikke igen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Are you sure you want to exit?</source>
        <translation>Er du sikker på, at du vil afslutte?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>En letvægts men kraftfuld multiplatform terminal emulator</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>Copyright (C) </source>
        <translation>Ophavsret (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>LXQt Project</source>
        <translation>LXQt Projektet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Development: </source>
        <translation>Udvikling: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Terminalindstillinger</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Udseende</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Opførsel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Genveje</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Rullegardin</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Bogmærker</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Skjul fanebladslinje når der kun er ét faneblad</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Farveskema</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Placering af rullebjælke</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Start med forudindstilling:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Vis en kant rundt om den nuværende terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Terminalens transparens</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Programmets transparens</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Ingen (én terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminaler vandret</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 terminaler lodret</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 terminaler</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Skift...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Placering af faneblade</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Vis menulinjen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Markørens form</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Skift vinduets titel baseret på nuværende terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Skift vinduets ikon baseret på nuværende terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Aktivér understøttelse af tovejstekst</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Baggrundsbillede:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Vælg</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Vis terminalens størrelse under tilpasning af størrelse</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Fast brede for faneblad:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Vis luk-knap på hvert faneblad</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Terminalmargin</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Brug bokstegningstegn i denne skrifttype</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Genveje aktiveres med Alt og kan forstyrre terminalen.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Ingen genveje for menulinje</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="830"/>
        <source>Emulation</source>
        <translation>Emulering</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Handling efter indsættelse</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="654"/>
        <source>Confirm multiline paste</source>
        <translation>Bekræft multilinjeindsættelse</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="661"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Fjern efterstillede linjeskift i indsat tekst</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new terminals in current working directory</source>
        <translation>Åbn nye terminaler i nuværende arbejdsmappe</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="692"/>
        <source>Save Size when closing</source>
        <translation>Gem størrelse ved lukning</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="685"/>
        <source>Save Position when closing</source>
        <translation>Gem placering ved lukning</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="678"/>
        <source>Ask for confirmation when closing</source>
        <translation>Spørg om bekræftelse ved lukning</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Ubegrænset historik</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Historikstørrelse (i linjer)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="781"/>
        <source>Default $TERM</source>
        <translation>Standard-$TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="704"/>
        <source>Start with this size:</source>
        <translation>Start med denne størrelse:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Baggrundstilstand:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Stræk</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Tilpas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Centrér</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Angiv om tegn der tegnes i en boks skal tegnes af QTerminal internt eller af underliggende skrifttypegengivelsesbiblioteker.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Skift anvendelse af fed skrift til gengivelse af intense farver til/fra</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Brug fed skrift til intense farver</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Skjul vindueskanter</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="839"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hvilken opførsel der skal emuleres. Bemærk at det ikke behøver være det samme som dit styresystem.&lt;/p&gt;&lt;p&gt;Hvis du er i tvivl, så brug &lt;span style=&quot; font-weight:600;&quot;&gt;standardemulering&lt;/span&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="817"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Kommandoen køres med et argument der indeholder filnavnet på en midlertidig fil der indeholder tilbagerulningshistorikken</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="820"/>
        <source>Handle history command</source>
        <translation>Håndter historikkommando</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <location filename="../forms/propertiesdialog.ui" line="725"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="732"/>
        <source>Get current size</source>
        <translation>Hent nuværende størrelse</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="767"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Åbn nyt faneblad til højre for det aktive faneblad</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Hvis den er fravalgt, så åbnes nye faneblade helt til højre</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Close tab on middle-click</source>
        <translation>Luk faneblad ved midterklik</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="647"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Deaktiver parentes indsæt tilstand med magt</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Word selection characters</source>
        <translation>Ordvalgstegn</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>Når du vælger tekst ved ord, skal du betragte disse tegn som en del af ordene ud over de alfanumeriske tegn</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Indsæt-tilstand med parentes er nyttig til at indsætte strenge med flere linjer.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="774"/>
        <source>Audible bell</source>
        <translation>Hørbar klokke</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="863"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Rediger en genvej:
1. Dobbeltklik på dens tast
2. Tryk på den ønskede kombination og slip den
3. Klik på en genvej eller tryk på enter

Fjern/deaktivér en genvej, i punkt 2, ved kun at trykke på en ændringstast (såsom Skift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Shortcut</source>
        <translation>Genvej</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Key</source>
        <translation>Tast</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Show on start</source>
        <translation>Vis ved start</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="917"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>En lås knap er vist på den lodrette tab bar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="920"/>
        <source>Keep window open when it loses focus</source>
        <translation>Hold vinduet åbent når det mister fokus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="927"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Height</source>
        <translation>Højde</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <location filename="../forms/propertiesdialog.ui" line="965"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>Width</source>
        <translation>Bredde</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="979"/>
        <source>Shortcut:</source>
        <translation>Genvej:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1046"/>
        <source>Edit bookmark file contents</source>
        <translation>Rediger indholdet af bogmærkefilen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1005"/>
        <source>Enable bookmarks</source>
        <translation>Aktivér bogmærker</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1014"/>
        <source>Bookmark file</source>
        <translation>Bogmærkefil</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1027"/>
        <source>Find...</source>
        <translation>Søg...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1036"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Du kan angive din egen placering af bogmærkefilen. Det giver mulighed for nemt at dele bogmærker med værktøjer såsom OwnCloud eller Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Ingen rullebjælke</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Blokmarkør</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Understreget markør</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>Lodret streg-markør</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Ingen flytning</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Ruller til toppen</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Ruller til bunden</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="271"/>
        <source>Examples</source>
        <translation>Eksempler</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="422"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Billeder (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="512"/>
        <source>Open bookmarks file</source>
        <translation>Åbne bogmærkefil</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>XML files (*.xml)</source>
        <translation>XML-filer (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="515"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="614"/>
        <location filename="../propertiesdialog.cpp" line="618"/>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="614"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Vil du overskrive denne bogmærke fil?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="618"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Navnet på bogmærkefilen ender ikke med &apos;.xml&apos;.
Er du sikker på du vil overskrive den?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="626"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="626"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>kan ikke skrive bogmærker til denne fil:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="206"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Systemstandard</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Choose a background image</source>
        <translation>Vælg et baggrundsbillede</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Synkroniserede bogmærker</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="81"/>
        <location filename="../tabwidget.cpp" line="235"/>
        <source>Shell No. %1</source>
        <translation>Skal nr. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>Tab name</source>
        <translation>Fanebladsnavn</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="204"/>
        <source>New tab name:</source>
        <translation>Nyt fanebladsnavn:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="224"/>
        <source>Select new tab title color</source>
        <translation>Vælg ny farve til titlen på faneblade</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="253"/>
        <source>Close session</source>
        <translation>Luk session</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="255"/>
        <source>Change title color</source>
        <translation>Skift farve på titlen</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>Indlæs session</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>Liste over gemte sessioner:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>HovedVindue</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Handlinger</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>H&amp;jælp</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Om...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Om &amp;Qt...</translation>
    </message>
</context>
</TS>
